## Berkeley Autolab Core Modules

[![Build Status](https://travis-ci.org/BerkeleyAutomation/autolab_core.svg?branch=master)](https://travis-ci.org/BerkeleyAutomation/autolab_core)

This module contains a set of useful utilities for robotic tasks.
View the install guide and API documentation
[here](https://BerkeleyAutomation.github.io/autolab_core).

NOTE: As of June 18, 2017, this package has been renamed from `core` to `autolab_core` to prevent naming conflicts.
If you wish to use the old version named `core`, please checkout the branch `pre_name_change`.
However, no further updates will be pushed to this branch.
